# -*- coding: utf-8 -*-
"""
@author: yq
@time: 2024/11/25
@desc: 特征筛选策略工厂
"""
from typing import Type

from commom import GeneralException
from enums import FilterStrategyEnum, ResultCodesEnum
from .filter_strategy_base import FilterStrategyBase
from .strategy_iv import StrategyIv

strategy_map = {
    FilterStrategyEnum.IV.value: StrategyIv
}


class FilterStrategyFactory():

    @staticmethod
    def get_strategy(strategy: str) -> Type[FilterStrategyBase]:
        if strategy not in strategy_map.keys():
            raise GeneralException(ResultCodesEnum.NOT_FOUND, message=f"特征搜索策略【{strategy}】不存在")
        strategy = strategy_map.get(strategy)
        return strategy
